@@ -1,7 +1,7 @@
 #!/bin/sh -x
 
-rm -fv ltmain.sh config.sub config.guess config.h.in aclocal.m4
-aclocal -I m4
+rm -fv ltmain.sh config.sub config.guess config.h.in aclocal.m4 -r m4
+aclocal
 autoheader
 libtoolize --automake --copy
 automake --add-missing --copy --force
